@@ -11,18 +11,27 @@
 #' ```
 #' MARKDOWN           LINK TEXT  CODE RD
 #' --------           ---------  ---- --
-#' [fun()]            fun()       T   \\link[=fun]{fun()}
-#' [obj]              obj         F   \\link{obj}
+#' [fun()]            fun()       T   \\link[=fun]{fun()} or
+#'                                    \\link[pkg:file]{pkg::fun()}
+#' [obj]              obj         F   \\link{obj} or
+#'                                    \\link[pkg:file]{pkg::obj}
 #' [pkg::fun()]       pkg::fun()  T   \\link[pkg:file]{pkg::fun()}
 #' [pkg::obj]         pkg::obj    F   \\link[pkg:file]{pkg::obj}
-#' [text][fun()]      text        F   \\link[=fun]{text}
-#' [text][obj]        text        F   \\link[=obj]{text}
+#' [text][fun()]      text        F   \\link[=fun]{text} or
+#'                                    \\link[pkg:file]{text}
+#' [text][obj]        text        F   \\link[=obj]{text} or
+#'                                    \\link[pkg:file]{text}
 #' [text][pkg::fun()] text        F   \\link[pkg:file]{text}
 #' [text][pkg::obj]   text        F   \\link[pkg:file]{text}
-#' [s4-class]         s4          F   \\linkS4class{s4}
+#' [s4-class]         s4          F   \\linkS4class{s4} or
+#'                                    \\link[pkg:file]{s4}
 #' [pkg::s4-class]    pkg::s4     F   \\link[pkg:file]{pkg::s4}
 #' ```
 #'
+#' For the links with two RD variants the first version is used for
+#' within-package links, and the second version is used for cross-package
+#' links.
+#'
 #' The reference links will always look like `R:ref` for `[ref]` and
 #' `[text][ref]`. These are explicitly tested in `test-rd-markdown-links.R`.
 #'
@@ -131,13 +140,15 @@ parse_link <- function(destination, contents, state) {
   is_code <- is_code || (grepl("[(][)]$", destination) && ! has_link_text)
   pkg <- str_match(destination, "^(.*)::")[1,2]
   pkg <- gsub("%", "\\\\%", pkg)
-  if (!is.na(pkg) && pkg == thispkg) pkg <- NA_character_
   fun <- utils::tail(strsplit(destination, "::", fixed = TRUE)[[1]], 1)
   fun <- gsub("%", "\\\\%", fun)
   is_fun <- grepl("[(][)]$", fun)
   obj <- sub("[(][)]$", "", fun)
   s4 <- str_detect(destination, "-class$")
   noclass <- str_match(fun, "^(.*)-class$")[1,2]
+
+  if (is.na(pkg)) pkg <- resolve_link_package(obj, thispkg, state = state)
+  if (!is.na(pkg) && pkg == thispkg) pkg <- NA_character_
   file <- find_topic_filename(pkg, obj, state$tag)
 
   ## To understand this, look at the RD column of the table above
@@ -174,6 +185,103 @@ parse_link <- function(destination, contents, state) {
   }
 }
 
+resolve_link_package <- function(topic, me = NULL, pkgdir = NULL, state = NULL) {
+  me <- me %||% roxy_meta_get("current_package")
+  # this is  from the roxygen2 tests, should not happen on a real package
+  if (is.null(me) || is.na(me) || me == "") return(NA_character_)
+
+  # if it is in the current package, then no need for package name, right?
+  if (has_topic(topic, me)) return(NA_character_)
+
+  # try packages in depends, imports, suggests first, error on name clashes
+  pkgs <- local_pkg_deps(pkgdir)
+
+  pkg_has_topic <- pkgs[map_lgl(pkgs, has_topic, topic = topic)]
+  pkg_has_topic <- map_chr(pkg_has_topic, function(p) {
+    p0 <- find_reexport_source(topic, p)
+    if (is.na(p0)) p else p0
+  })
+  pkg_has_topic <- unique(pkg_has_topic)
+  base <- base_packages()
+  if (length(pkg_has_topic) == 0) {
+    # fall through to check base packages as well
+  } else if (length(pkg_has_topic) == 1) {
+    if (pkg_has_topic %in% base) {
+      return(NA_character_)
+    } else {
+      return(pkg_has_topic)
+    }
+  } else {
+    warn_roxy_tag(state$tag, c(
+      "Topic {.val {topic}} is available in multiple packages: {.pkg {pkg_has_topic}}",
+      i = "Qualify topic explicitly with a package name when linking to it."
+    ))
+    return(NA_character_)
+  }
+
+  # try base packages as well, take the first hit,
+  # there should not be any name clashes, anyway
+  for (bp in base) {
+    if (has_topic(topic, bp)) return(NA_character_)
+  }
+
+  warn_roxy_tag(state$tag, c(
+    "Could not resolve link to topic {.val {topic}} in the dependencies or base packages",
+    "i" = paste(
+      "If you haven't documented {.val {topic}} yet, or just changed its name, this is normal.",
+      "Once {.val {topic}} is documented, this warning goes away."),
+    "i" = "Make sure that the name of the topic is spelled correctly.",
+    "i" = "Always list the linked package as a dependency.",
+    "i" = "Alternatively, you can fully qualify the link with a package name."
+  ))
+
+  NA_character_
+}
+
+# this is mostly from downlit
+is_exported <- function(name, package) {
+  name %in% getNamespaceExports(ns_env(package))
+}
+
+is_reexported <- function(name, package) {
+  if (package == "base") {
+    return(FALSE)
+  }
+  is_imported <- env_has(ns_imports_env(package), name)
+  is_imported && is_exported(name, package)
+}
+
+find_reexport_source <- function(topic, package) {
+  ns <- ns_env(package)
+  if (!env_has(ns, topic, inherit = TRUE)) {
+    return(NA_character_)
+  }
+
+  obj <- env_get(ns, topic, inherit = TRUE)
+  if (is.primitive(obj)) {
+    # primitive functions all live in base
+    "base"
+  } else if (is.function(obj)) {
+    ## For functions, we can just take their environment.
+    ns_env_name(get_env(obj))
+  } else {
+    ## For other objects, we need to check the import env of the package,
+    ## to see where 'topic' is coming from. The import env has redundant
+    ## information. It seems that we just need to find a named list
+    ## entry that contains `topic`.
+    imp <- getNamespaceImports(ns)
+    imp <- imp[names(imp) != ""]
+    wpkgs <- vapply(imp, `%in%`, x = topic, FUN.VALUE = logical(1))
+
+    if (!any(wpkgs)) {
+      return(NA_character_)
+    }
+    pkgs <- names(wpkgs)[wpkgs]
+    # Take the last match, in case imports have name clashes.
+    pkgs[[length(pkgs)]]
+  }
+}
+
 #' Dummy page to test roxygen's markdown formatting
 #'
 #' Links are very tricky, so I'll put in some links here:
