@@ -38,12 +38,15 @@ roxygenize <- function(package.dir = ".",
   lapply(packages, loadNamespace)
 
   roclets <- roclets %||% roxy_meta_get("roclets")
-  # Special case collate: it doesn't need to execute code, and must be run
-  # first to ensure that code can be executed
+
+  # To load code, we need a up-to-date Collate field and NAMESPACE
   if ("collate" %in% roclets) {
     update_collate(base_path)
     roclets <- setdiff(roclets, "collate")
   }
+  if ("namespace" %in% roclets) {
+    update_namespace_imports(base_path)
+  }
 
   if (length(roclets) == 0)
     return(invisible())
@@ -57,8 +60,7 @@ roxygenize <- function(package.dir = ".",
   # Now load code
   load_code <- find_load_strategy(load_code)
   env <- load_code(base_path)
-  roxy_meta_set("env", env)
-  on.exit(roxy_meta_set("env", NULL), add = TRUE)
+  local_roxy_meta_set("env", env)
 
   # Tokenise each file
   blocks <- parse_package(base_path, env = NULL)
