@@ -1,5 +1,7 @@
 test_that("format has nice defaults for bare vectors", {
-  verify_output(test_path("test-object-format.txt"), {
+  skip_if(getRversion() <= "4.0.0")
+
+  expect_snapshot({
     call_to_format(x <- list(a = 1, b = 2))
     call_to_format(x <- ordered(letters[1:5]))
     call_to_format(x <- diag(10))
