@@ -12,11 +12,14 @@ test_that("primitive generics detected", {
 test_that("non-functions are not generics", {
   a <- TRUE
   b <- NULL
-  c <- data.frame()
 
   expect_false(is_s3_generic("a"))
   expect_false(is_s3_generic("b"))
-  expect_false(is_s3_generic("c"))
+})
+
+test_that("ignores non-function objects when looking for generics", {
+  c <- data.frame()
+  expect_true(is_s3_generic("c"))
 })
 
 test_that("user defined generics & methods detected", {
@@ -50,13 +53,3 @@ test_that("user defined functions override primitives", {
   expect_false(is_s3_generic("c"))
   expect_false(is_s3_method("c"))
 })
-
-test_that("@method overrides auto-detection", {
-  out <- parse_text("
-    #' @export
-    #' @method all.equal data.frame
-    all.equal.data.frame <- function(...) 1
-  ")[[1]]
-
-  expect_equal(s3_method_info(out$object$value), c("all.equal", "data.frame"))
-})
