@@ -9,28 +9,6 @@ test_that("rawRd inserted unchanged", {
   expect_equal(lines[[9]], "#this is a comment")
 })
 
-test_that("evalRd must be valid code", {
-  expect_warning(
-    roc_proc_text(rd_roclet(), "
-      #' @evalRd a +
-      #' @name a
-      #' @title a
-      NULL"),
-    "code failed to parse"
-  )
-})
-
-test_that("error-ful evalRd generates warning", {
-  expect_warning(
-    roc_proc_text(rd_roclet(), "
-      #' @evalRd stop('!')
-      #' @name a
-      #' @title a
-      NULL"),
-    "failed with error"
-  )
-})
-
 test_that("evalRd inserted unchanged", {
   out <- roc_proc_text(rd_roclet(), "
     z <- 10
@@ -41,3 +19,12 @@ test_that("evalRd inserted unchanged", {
 
   expect_equal(out$get_value("rawRd"), "20")
 })
+
+test_that("error-ful evalRd generates warning", {
+  expect_snapshot({
+    expect_parse_failure(roxy_tag_eval(roxy_test_tag(val = 1)))
+    expect_parse_failure(roxy_tag_eval(roxy_test_tag(val = NA_character_)))
+    expect_parse_failure(roxy_tag_eval(roxy_test_tag(val = quote(stop('Uhoh')))))
+  })
+})
+
